@@ -1,6 +1,6 @@
 package Math::GMPn;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use strict;
 use warnings;
@@ -12,6 +12,7 @@ our @EXPORT = qw( GMP_LIMB_BITS
                   GMP_LIMB_BYTES
 
                   mpn_neg
+                  mpn_not
                   mpn_add
                   mpn_sub
                   mpn_mul
@@ -319,6 +320,14 @@ to:
 
   $u = ($s1 >> $bitix ) & $mask;
 
+=item mpn_not($r, $s1)
+
+  $r = ~$s1
+
+=item mpn_neg($r, $s1)
+
+  $r = -$s1
+
 =item mpn_ior($r, $s1, $s2)
 
   $r = $s1 | $s2
